==> apache-camel-4.5.0-src.zip: apache-camel-4.5.0/core/camel-core-model/src/main/java/org/apache/camel/model/PipelineDefinition.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.model;

import java.util.List;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElementRef;
import jakarta.xml.bind.annotation.XmlRootElement;

import org.apache.camel.spi.Metadata;

/**
 * Routes the message to a sequence of processors.
 */
@Metadata(label = "eip,routing")
@XmlRootElement(name = "pipeline")
@XmlAccessorType(XmlAccessType.FIELD)
public class PipelineDefinition extends OutputDefinition<PipelineDefinition> {

    public PipelineDefinition() {
    }

    @Override
    public List<ProcessorDefinition<?>> getOutputs() {
        return outputs;
    }

    @XmlElementRef
    @Override
    public void setOutputs(List<ProcessorDefinition<?>> outputs) {
        super.setOutputs(outputs);
    }

    @Override
    public String getShortName() {
        return "pipeline";
    }

    @Override
    public String getLabel() {
        return "pipeline";
    }

}

==> apache-camel-4.12.0-src.zip: apache-camel-4.12.0/core/camel-core-model/src/main/java/org/apache/camel/model/PipelineDefinition.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.model;

import java.util.List;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElementRef;
import jakarta.xml.bind.annotation.XmlRootElement;

import org.apache.camel.spi.Metadata;

/**
 * Routes the message to a sequence of processors.
 */
@Metadata(label = "eip,routing")
@XmlRootElement(name = "pipeline")
@XmlAccessorType(XmlAccessType.FIELD)
public class PipelineDefinition extends OutputDefinition<PipelineDefinition> {

    public PipelineDefinition() {
    }

    protected PipelineDefinition(PipelineDefinition source) {
        super(source);
    }

    @Override
    public PipelineDefinition copyDefinition() {
        return new PipelineDefinition(this);
    }

    @Override
    public List<ProcessorDefinition<?>> getOutputs() {
        return outputs;
    }

    @XmlElementRef
    @Override
    public void setOutputs(List<ProcessorDefinition<?>> outputs) {
        super.setOutputs(outputs);
    }

    @Override
    public String getShortName() {
        return "pipeline";
    }

    @Override
    public String getLabel() {
        return "pipeline";
    }

}
